
# Slot: code_set_version


the version identifier of the enumeration code set

URI: [linkml:code_set_version](https://w3id.org/linkml/code_set_version)


## Domain and Range

[EnumDefinition](EnumDefinition.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [EnumDefinition](EnumDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | we assume that version identifiers lexically sort in temporal order. Recommend semver when possible |

